use egui::{CentralPanel, Context, Image, ViewportBuilder, ViewportId};

use super::AppWindow;

pub struct AboutWindow;

impl AppWindow for AboutWindow {
    fn viewport_id(&self) -> ViewportId {
        ViewportId::from_hash_of("About")
    }

    fn initial_viewport(&self) -> ViewportBuilder {
        ViewportBuilder::default()
            .with_title("About Lemur")
            .with_inner_size((300.0, 200.0))
    }

    fn show(&mut self, ctx: &Context) {
        CentralPanel::default().show(ctx, |ui| {
            ui.vertical_centered(|ui| {
                ui.label("Lemur Virtual Boy Emulator");
                ui.label(format!("Version {}", env!("CARGO_PKG_VERSION")));
                ui.hyperlink("https://git.virtual-boy.com/PVB/lemur");
                let logo = Image::new(egui::include_image!("../../assets/lemur-256x256.png"))
                    .max_width(256.0)
                    .maintain_aspect_ratio(true);
                ui.add(logo);
            });
        });
    }
}
